# Copyright 2025 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl).

from openupgradelib import openupgrade

_xmlids_renames = [
    (
        "l10n_fr.account_fr_tag_charges_sociales",
        "l10n_fr_account.account_fr_tag_charges_sociales",
    ),
    ("l10n_fr.account_fr_tag_salaires", "l10n_fr_account.account_fr_tag_salaires"),
    ("l10n_fr.tax_report", "l10n_fr_account.tax_report"),
    ("l10n_fr.tax_report_adjustment", "l10n_fr_account.tax_report_adjustment"),
    ("l10n_fr.tax_report_balance", "l10n_fr_account.tax_report_balance"),
    (
        "l10n_fr.tax_report_08_base_adjustment",
        "l10n_fr_account.tax_report_08_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_08_base_balance_from_tags",
        "l10n_fr_account.tax_report_08_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_08_base_tag", "l10n_fr_account.tax_report_08_base_tag"),
    ("l10n_fr.tax_report_08_taxe_tag", "l10n_fr_account.tax_report_08_taxe_tag"),
    (
        "l10n_fr.tax_report_08_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_08_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_09_base_adjustment",
        "l10n_fr_account.tax_report_09_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_09_base_balance_from_tags",
        "l10n_fr_account.tax_report_09_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_09_base_tag", "l10n_fr_account.tax_report_09_base_tag"),
    ("l10n_fr.tax_report_09_taxe_tag", "l10n_fr_account.tax_report_09_taxe_tag"),
    (
        "l10n_fr.tax_report_09_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_09_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_10_base_adjustment",
        "l10n_fr_account.tax_report_10_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_10_base_balance_from_tags",
        "l10n_fr_account.tax_report_10_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_10_base_tag", "l10n_fr_account.tax_report_10_base_tag"),
    ("l10n_fr.tax_report_10_taxe_tag", "l10n_fr_account.tax_report_10_taxe_tag"),
    (
        "l10n_fr.tax_report_10_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_10_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_11_base_adjustment",
        "l10n_fr_account.tax_report_11_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_11_base_balance_from_tags",
        "l10n_fr_account.tax_report_11_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_11_base_tag", "l10n_fr_account.tax_report_11_base_tag"),
    ("l10n_fr.tax_report_11_taxe_tag", "l10n_fr_account.tax_report_11_taxe_tag"),
    (
        "l10n_fr.tax_report_11_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_11_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_13_base_adjustment",
        "l10n_fr_account.tax_report_13_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_13_base_balance_from_tags",
        "l10n_fr_account.tax_report_13_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_13_base_tag", "l10n_fr_account.tax_report_13_base_tag"),
    ("l10n_fr.tax_report_13_taxe_tag", "l10n_fr_account.tax_report_13_taxe_tag"),
    (
        "l10n_fr.tax_report_14_base_adjustment",
        "l10n_fr_account.tax_report_14_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_14_base_balance_from_tags",
        "l10n_fr_account.tax_report_14_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_14_base_tag", "l10n_fr_account.tax_report_14_base_tag"),
    ("l10n_fr.tax_report_14_taxe_tag", "l10n_fr_account.tax_report_14_taxe_tag"),
    ("l10n_fr.tax_report_15_1_tag", "l10n_fr_account.tax_report_15_1_tag"),
    ("l10n_fr.tax_report_15_2_tag", "l10n_fr_account.tax_report_15_2_tag"),
    ("l10n_fr.tax_report_15_tag", "l10n_fr_account.tax_report_15_tag"),
    ("l10n_fr.tax_report_16_formula", "l10n_fr_account.tax_report_16_formula"),
    ("l10n_fr.tax_report_17_tag", "l10n_fr_account.tax_report_17_tag"),
    ("l10n_fr.tax_report_18_tag", "l10n_fr_account.tax_report_18_tag"),
    ("l10n_fr.tax_report_19_tag", "l10n_fr_account.tax_report_19_tag"),
    ("l10n_fr.tax_report_20_tag", "l10n_fr_account.tax_report_20_tag"),
    ("l10n_fr.tax_report_21_tag", "l10n_fr_account.tax_report_21_tag"),
    ("l10n_fr.tax_report_22A_tag", "l10n_fr_account.tax_report_22A_tag"),
    (
        "l10n_fr.tax_report_22_applied_carryover",
        "l10n_fr_account.tax_report_22_applied_carryover",
    ),
    ("l10n_fr.tax_report_22_balance", "l10n_fr_account.tax_report_22_balance"),
    ("l10n_fr.tax_report_22_tag", "l10n_fr_account.tax_report_22_tag"),
    ("l10n_fr.tax_report_23_formula", "l10n_fr_account.tax_report_23_formula"),
    ("l10n_fr.tax_report_24_tag", "l10n_fr_account.tax_report_24_tag"),
    ("l10n_fr.tax_report_25_formula", "l10n_fr_account.tax_report_25_formula"),
    ("l10n_fr.tax_report_27_carryover", "l10n_fr_account.tax_report_27_carryover"),
    ("l10n_fr.tax_report_27_formula", "l10n_fr_account.tax_report_27_formula"),
    (
        "l10n_fr.tax_report_27_formula_temp",
        "l10n_fr_account.tax_report_27_formula_temp",
    ),
    ("l10n_fr.tax_report_28_formula", "l10n_fr_account.tax_report_28_formula"),
    ("l10n_fr.tax_report_29_tag", "l10n_fr_account.tax_report_29_tag"),
    ("l10n_fr.tax_report_2C_tag", "l10n_fr_account.tax_report_2C_tag"),
    ("l10n_fr.tax_report_2E_tag", "l10n_fr_account.tax_report_2E_tag"),
    ("l10n_fr.tax_report_32_formula", "l10n_fr_account.tax_report_32_formula"),
    ("l10n_fr.tax_report_5B_tag", "l10n_fr_account.tax_report_5B_tag"),
    (
        "l10n_fr.tax_report_9B_base_adjustment",
        "l10n_fr_account.tax_report_9B_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_9B_base_balance_from_tags",
        "l10n_fr_account.tax_report_9B_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_9B_base_tag", "l10n_fr_account.tax_report_9B_base_tag"),
    ("l10n_fr.tax_report_9B_taxe_tag", "l10n_fr_account.tax_report_9B_taxe_tag"),
    (
        "l10n_fr.tax_report_9B_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_9B_taxe_tag_no_rounding",
    ),
    ("l10n_fr.tax_report_A1_adjustment", "l10n_fr_account.tax_report_A1_adjustment"),
    (
        "l10n_fr.tax_report_A1_balance_from_tags",
        "l10n_fr_account.tax_report_A1_balance_from_tags",
    ),
    ("l10n_fr.tax_report_A1_tag", "l10n_fr_account.tax_report_A1_tag"),
    ("l10n_fr.tax_report_A2_adjustment", "l10n_fr_account.tax_report_A2_adjustment"),
    (
        "l10n_fr.tax_report_A2_balance_from_tags",
        "l10n_fr_account.tax_report_A2_balance_from_tags",
    ),
    ("l10n_fr.tax_report_A2_tag", "l10n_fr_account.tax_report_A2_tag"),
    ("l10n_fr.tax_report_A3_adjustment", "l10n_fr_account.tax_report_A3_adjustment"),
    (
        "l10n_fr.tax_report_A3_balance_from_tags",
        "l10n_fr_account.tax_report_A3_balance_from_tags",
    ),
    ("l10n_fr.tax_report_A3_tag", "l10n_fr_account.tax_report_A3_tag"),
    ("l10n_fr.tax_report_A4_adjustment", "l10n_fr_account.tax_report_A4_adjustment"),
    (
        "l10n_fr.tax_report_A4_balance_from_tags",
        "l10n_fr_account.tax_report_A4_balance_from_tags",
    ),
    ("l10n_fr.tax_report_A4_tag", "l10n_fr_account.tax_report_A4_tag"),
    ("l10n_fr.tax_report_A5_adjustment", "l10n_fr_account.tax_report_A5_adjustment"),
    (
        "l10n_fr.tax_report_A5_balance_from_tags",
        "l10n_fr_account.tax_report_A5_balance_from_tags",
    ),
    ("l10n_fr.tax_report_A5_tag", "l10n_fr_account.tax_report_A5_tag"),
    ("l10n_fr.tax_report_AA_tag", "l10n_fr_account.tax_report_AA_tag"),
    ("l10n_fr.tax_report_B1_adjustment", "l10n_fr_account.tax_report_B1_adjustment"),
    (
        "l10n_fr.tax_report_B1_balance_from_tags",
        "l10n_fr_account.tax_report_B1_balance_from_tags",
    ),
    ("l10n_fr.tax_report_B1_tag", "l10n_fr_account.tax_report_B1_tag"),
    ("l10n_fr.tax_report_B2_adjustment", "l10n_fr_account.tax_report_B2_adjustment"),
    (
        "l10n_fr.tax_report_B2_balance_from_tags",
        "l10n_fr_account.tax_report_B2_balance_from_tags",
    ),
    ("l10n_fr.tax_report_B2_tag", "l10n_fr_account.tax_report_B2_tag"),
    ("l10n_fr.tax_report_B3_adjustment", "l10n_fr_account.tax_report_B3_adjustment"),
    (
        "l10n_fr.tax_report_B3_balance_from_tags",
        "l10n_fr_account.tax_report_B3_balance_from_tags",
    ),
    ("l10n_fr.tax_report_B3_tag", "l10n_fr_account.tax_report_B3_tag"),
    ("l10n_fr.tax_report_B4_adjustment", "l10n_fr_account.tax_report_B4_adjustment"),
    (
        "l10n_fr.tax_report_B4_balance_from_tags",
        "l10n_fr_account.tax_report_B4_balance_from_tags",
    ),
    ("l10n_fr.tax_report_B4_tag", "l10n_fr_account.tax_report_B4_tag"),
    ("l10n_fr.tax_report_B5_adjustment", "l10n_fr_account.tax_report_B5_adjustment"),
    (
        "l10n_fr.tax_report_B5_balance_from_tags",
        "l10n_fr_account.tax_report_B5_balance_from_tags",
    ),
    ("l10n_fr.tax_report_B5_tag", "l10n_fr_account.tax_report_B5_tag"),
    ("l10n_fr.tax_report_E1_adjustment", "l10n_fr_account.tax_report_E1_adjustment"),
    (
        "l10n_fr.tax_report_E1_balance_from_tags",
        "l10n_fr_account.tax_report_E1_balance_from_tags",
    ),
    ("l10n_fr.tax_report_E1_tag", "l10n_fr_account.tax_report_E1_tag"),
    ("l10n_fr.tax_report_E2_adjustment", "l10n_fr_account.tax_report_E2_adjustment"),
    (
        "l10n_fr.tax_report_E2_balance_from_tags",
        "l10n_fr_account.tax_report_E2_balance_from_tags",
    ),
    ("l10n_fr.tax_report_E2_tag", "l10n_fr_account.tax_report_E2_tag"),
    ("l10n_fr.tax_report_E3_adjustment", "l10n_fr_account.tax_report_E3_adjustment"),
    (
        "l10n_fr.tax_report_E3_balance_from_tags",
        "l10n_fr_account.tax_report_E3_balance_from_tags",
    ),
    ("l10n_fr.tax_report_E3_tag", "l10n_fr_account.tax_report_E3_tag"),
    ("l10n_fr.tax_report_E4_adjustment", "l10n_fr_account.tax_report_E4_adjustment"),
    (
        "l10n_fr.tax_report_E4_balance_from_tags",
        "l10n_fr_account.tax_report_E4_balance_from_tags",
    ),
    ("l10n_fr.tax_report_E4_tag", "l10n_fr_account.tax_report_E4_tag"),
    ("l10n_fr.tax_report_E5_adjustment", "l10n_fr_account.tax_report_E5_adjustment"),
    (
        "l10n_fr.tax_report_E5_balance_from_tags",
        "l10n_fr_account.tax_report_E5_balance_from_tags",
    ),
    ("l10n_fr.tax_report_E5_tag", "l10n_fr_account.tax_report_E5_tag"),
    ("l10n_fr.tax_report_E6_adjustment", "l10n_fr_account.tax_report_E6_adjustment"),
    (
        "l10n_fr.tax_report_E6_balance_from_tags",
        "l10n_fr_account.tax_report_E6_balance_from_tags",
    ),
    ("l10n_fr.tax_report_E6_tag", "l10n_fr_account.tax_report_E6_tag"),
    ("l10n_fr.tax_report_F1_adjustment", "l10n_fr_account.tax_report_F1_adjustment"),
    (
        "l10n_fr.tax_report_F1_balance_from_tags",
        "l10n_fr_account.tax_report_F1_balance_from_tags",
    ),
    ("l10n_fr.tax_report_F1_tag", "l10n_fr_account.tax_report_F1_tag"),
    ("l10n_fr.tax_report_F2_adjustment", "l10n_fr_account.tax_report_F2_adjustment"),
    (
        "l10n_fr.tax_report_F2_balance_from_tags",
        "l10n_fr_account.tax_report_F2_balance_from_tags",
    ),
    ("l10n_fr.tax_report_F2_tag", "l10n_fr_account.tax_report_F2_tag"),
    ("l10n_fr.tax_report_F3_adjustment", "l10n_fr_account.tax_report_F3_adjustment"),
    (
        "l10n_fr.tax_report_F3_balance_from_tags",
        "l10n_fr_account.tax_report_F3_balance_from_tags",
    ),
    ("l10n_fr.tax_report_F3_tag", "l10n_fr_account.tax_report_F3_tag"),
    ("l10n_fr.tax_report_F4_adjustment", "l10n_fr_account.tax_report_F4_adjustment"),
    (
        "l10n_fr.tax_report_F4_balance_from_tags",
        "l10n_fr_account.tax_report_F4_balance_from_tags",
    ),
    ("l10n_fr.tax_report_F4_tag", "l10n_fr_account.tax_report_F4_tag"),
    ("l10n_fr.tax_report_F5_adjustment", "l10n_fr_account.tax_report_F5_adjustment"),
    (
        "l10n_fr.tax_report_F5_balance_from_tags",
        "l10n_fr_account.tax_report_F5_balance_from_tags",
    ),
    ("l10n_fr.tax_report_F5_tag", "l10n_fr_account.tax_report_F5_tag"),
    ("l10n_fr.tax_report_F6_adjustment", "l10n_fr_account.tax_report_F6_adjustment"),
    (
        "l10n_fr.tax_report_F6_balance_from_tags",
        "l10n_fr_account.tax_report_F6_balance_from_tags",
    ),
    ("l10n_fr.tax_report_F6_tag", "l10n_fr_account.tax_report_F6_tag"),
    ("l10n_fr.tax_report_F7_adjustment", "l10n_fr_account.tax_report_F7_adjustment"),
    (
        "l10n_fr.tax_report_F7_balance_from_tags",
        "l10n_fr_account.tax_report_F7_balance_from_tags",
    ),
    ("l10n_fr.tax_report_F7_tag", "l10n_fr_account.tax_report_F7_tag"),
    ("l10n_fr.tax_report_F8_adjustment", "l10n_fr_account.tax_report_F8_adjustment"),
    (
        "l10n_fr.tax_report_F8_balance_from_tags",
        "l10n_fr_account.tax_report_F8_balance_from_tags",
    ),
    ("l10n_fr.tax_report_F8_tag", "l10n_fr_account.tax_report_F8_tag"),
    ("l10n_fr.tax_report_F9_adjustment", "l10n_fr_account.tax_report_F9_adjustment"),
    (
        "l10n_fr.tax_report_F9_balance_from_tags",
        "l10n_fr_account.tax_report_F9_balance_from_tags",
    ),
    ("l10n_fr.tax_report_F9_tag", "l10n_fr_account.tax_report_F9_tag"),
    (
        "l10n_fr.tax_report_I1_base_adjustment",
        "l10n_fr_account.tax_report_I1_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_I1_base_balance_from_tags",
        "l10n_fr_account.tax_report_I1_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_I1_base_tag", "l10n_fr_account.tax_report_I1_base_tag"),
    ("l10n_fr.tax_report_I1_taxe_tag", "l10n_fr_account.tax_report_I1_taxe_tag"),
    (
        "l10n_fr.tax_report_I1_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_I1_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_I2_base_adjustment",
        "l10n_fr_account.tax_report_I2_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_I2_base_balance_from_tags",
        "l10n_fr_account.tax_report_I2_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_I2_base_tag", "l10n_fr_account.tax_report_I2_base_tag"),
    ("l10n_fr.tax_report_I2_taxe_tag", "l10n_fr_account.tax_report_I2_taxe_tag"),
    (
        "l10n_fr.tax_report_I2_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_I2_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_I3_base_adjustment",
        "l10n_fr_account.tax_report_I3_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_I3_base_balance_from_tags",
        "l10n_fr_account.tax_report_I3_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_I3_base_tag", "l10n_fr_account.tax_report_I3_base_tag"),
    ("l10n_fr.tax_report_I3_taxe_tag", "l10n_fr_account.tax_report_I3_taxe_tag"),
    (
        "l10n_fr.tax_report_I3_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_I3_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_I4_base_adjustment",
        "l10n_fr_account.tax_report_I4_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_I4_base_balance_from_tags",
        "l10n_fr_account.tax_report_I4_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_I4_base_tag", "l10n_fr_account.tax_report_I4_base_tag"),
    ("l10n_fr.tax_report_I4_taxe_tag", "l10n_fr_account.tax_report_I4_taxe_tag"),
    (
        "l10n_fr.tax_report_I4_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_I4_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_I5_base_adjustment",
        "l10n_fr_account.tax_report_I5_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_I5_base_balance_from_tags",
        "l10n_fr_account.tax_report_I5_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_I5_base_tag", "l10n_fr_account.tax_report_I5_base_tag"),
    ("l10n_fr.tax_report_I5_taxe_tag", "l10n_fr_account.tax_report_I5_taxe_tag"),
    (
        "l10n_fr.tax_report_I5_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_I5_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_I6_base_adjustment",
        "l10n_fr_account.tax_report_I6_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_I6_base_balance_from_tags",
        "l10n_fr_account.tax_report_I6_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_I6_base_tag", "l10n_fr_account.tax_report_I6_base_tag"),
    ("l10n_fr.tax_report_I6_taxe_tag", "l10n_fr_account.tax_report_I6_taxe_tag"),
    (
        "l10n_fr.tax_report_I6_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_I6_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_P1_base_adjustment",
        "l10n_fr_account.tax_report_P1_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_P1_base_balance_from_tags",
        "l10n_fr_account.tax_report_P1_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_P1_base_tag", "l10n_fr_account.tax_report_P1_base_tag"),
    ("l10n_fr.tax_report_P1_taxe_tag", "l10n_fr_account.tax_report_P1_taxe_tag"),
    (
        "l10n_fr.tax_report_P1_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_P1_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_P2_base_adjustment",
        "l10n_fr_account.tax_report_P2_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_P2_base_balance_from_tags",
        "l10n_fr_account.tax_report_P2_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_P2_base_tag", "l10n_fr_account.tax_report_P2_base_tag"),
    ("l10n_fr.tax_report_P2_taxe_tag", "l10n_fr_account.tax_report_P2_taxe_tag"),
    (
        "l10n_fr.tax_report_P2_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_P2_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_T1_base_adjustment",
        "l10n_fr_account.tax_report_T1_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_T1_base_balance_from_tags",
        "l10n_fr_account.tax_report_T1_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_T1_base_tag", "l10n_fr_account.tax_report_T1_base_tag"),
    ("l10n_fr.tax_report_T1_taxe_tag", "l10n_fr_account.tax_report_T1_taxe_tag"),
    (
        "l10n_fr.tax_report_T1_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_T1_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_T2_base_adjustment",
        "l10n_fr_account.tax_report_T2_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_T2_base_balance_from_tags",
        "l10n_fr_account.tax_report_T2_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_T2_base_tag", "l10n_fr_account.tax_report_T2_base_tag"),
    ("l10n_fr.tax_report_T2_taxe_tag", "l10n_fr_account.tax_report_T2_taxe_tag"),
    (
        "l10n_fr.tax_report_T2_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_T2_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_T3_base_adjustment",
        "l10n_fr_account.tax_report_T3_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_T3_base_balance_from_tags",
        "l10n_fr_account.tax_report_T3_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_T3_base_tag", "l10n_fr_account.tax_report_T3_base_tag"),
    ("l10n_fr.tax_report_T3_taxe_tag", "l10n_fr_account.tax_report_T3_taxe_tag"),
    (
        "l10n_fr.tax_report_T3_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_T3_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_T4_base_adjustment",
        "l10n_fr_account.tax_report_T4_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_T4_base_balance_from_tags",
        "l10n_fr_account.tax_report_T4_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_T4_base_tag", "l10n_fr_account.tax_report_T4_base_tag"),
    ("l10n_fr.tax_report_T4_taxe_tag", "l10n_fr_account.tax_report_T4_taxe_tag"),
    (
        "l10n_fr.tax_report_T4_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_T4_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_T5_base_adjustment",
        "l10n_fr_account.tax_report_T5_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_T5_base_balance_from_tags",
        "l10n_fr_account.tax_report_T5_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_T5_base_tag", "l10n_fr_account.tax_report_T5_base_tag"),
    ("l10n_fr.tax_report_T5_taxe_tag", "l10n_fr_account.tax_report_T5_taxe_tag"),
    (
        "l10n_fr.tax_report_T5_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_T5_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_T6_base_adjustment",
        "l10n_fr_account.tax_report_T6_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_T6_base_balance_from_tags",
        "l10n_fr_account.tax_report_T6_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_T6_base_tag", "l10n_fr_account.tax_report_T6_base_tag"),
    ("l10n_fr.tax_report_T6_taxe_tag", "l10n_fr_account.tax_report_T6_taxe_tag"),
    (
        "l10n_fr.tax_report_T6_taxe_tag_no_rounding",
        "l10n_fr_account.tax_report_T6_taxe_tag_no_rounding",
    ),
    (
        "l10n_fr.tax_report_T7_base_adjustment",
        "l10n_fr_account.tax_report_T7_base_adjustment",
    ),
    (
        "l10n_fr.tax_report_T7_base_balance_from_tags",
        "l10n_fr_account.tax_report_T7_base_balance_from_tags",
    ),
    ("l10n_fr.tax_report_T7_base_tag", "l10n_fr_account.tax_report_T7_base_tag"),
    ("l10n_fr.tax_report_T7_taxe_tag", "l10n_fr_account.tax_report_T7_taxe_tag"),
    ("l10n_fr.tax_report_TICC_tag", "l10n_fr_account.tax_report_TICC_tag"),
    ("l10n_fr.tax_report_TICFE_tag", "l10n_fr_account.tax_report_TICFE_tag"),
    ("l10n_fr.tax_report_TICGN_tag", "l10n_fr_account.tax_report_TICGN_tag"),
    (
        "l10n_fr.tax_report_TIC_total_formula",
        "l10n_fr_account.tax_report_TIC_total_formula",
    ),
    ("l10n_fr.tax_report_X1_tag", "l10n_fr_account.tax_report_X1_tag"),
    ("l10n_fr.tax_report_X2_tag", "l10n_fr_account.tax_report_X2_tag"),
    ("l10n_fr.tax_report_X3_tag", "l10n_fr_account.tax_report_X3_tag"),
    ("l10n_fr.tax_report_X4_formula", "l10n_fr_account.tax_report_X4_formula"),
    ("l10n_fr.tax_report_Y1_formula", "l10n_fr_account.tax_report_Y1_formula"),
    ("l10n_fr.tax_report_Y2_formula", "l10n_fr_account.tax_report_Y2_formula"),
    ("l10n_fr.tax_report_Y3_formula", "l10n_fr_account.tax_report_Y3_formula"),
    ("l10n_fr.tax_report_Z1_tag", "l10n_fr_account.tax_report_Z1_tag"),
    ("l10n_fr.tax_report_Z2_tag", "l10n_fr_account.tax_report_Z2_tag"),
    ("l10n_fr.tax_report_Z3_tag", "l10n_fr_account.tax_report_Z3_tag"),
    ("l10n_fr.tax_report_Z4_formula", "l10n_fr_account.tax_report_Z4_formula"),
    ("l10n_fr.tax_report_td_formula", "l10n_fr_account.tax_report_td_formula"),
    ("l10n_fr.tax_report_08_base", "l10n_fr_account.tax_report_08_base"),
    ("l10n_fr.tax_report_08_taxe", "l10n_fr_account.tax_report_08_taxe"),
    ("l10n_fr.tax_report_09_base", "l10n_fr_account.tax_report_09_base"),
    ("l10n_fr.tax_report_09_taxe", "l10n_fr_account.tax_report_09_taxe"),
    ("l10n_fr.tax_report_10_base", "l10n_fr_account.tax_report_10_base"),
    ("l10n_fr.tax_report_10_taxe", "l10n_fr_account.tax_report_10_taxe"),
    ("l10n_fr.tax_report_11_base", "l10n_fr_account.tax_report_11_base"),
    ("l10n_fr.tax_report_11_taxe", "l10n_fr_account.tax_report_11_taxe"),
    ("l10n_fr.tax_report_13_base", "l10n_fr_account.tax_report_13_base"),
    ("l10n_fr.tax_report_13_taxe", "l10n_fr_account.tax_report_13_taxe"),
    ("l10n_fr.tax_report_14_base", "l10n_fr_account.tax_report_14_base"),
    ("l10n_fr.tax_report_14_taxe", "l10n_fr_account.tax_report_14_taxe"),
    ("l10n_fr.tax_report_15", "l10n_fr_account.tax_report_15"),
    ("l10n_fr.tax_report_15_1", "l10n_fr_account.tax_report_15_1"),
    ("l10n_fr.tax_report_15_2", "l10n_fr_account.tax_report_15_2"),
    ("l10n_fr.tax_report_16", "l10n_fr_account.tax_report_16"),
    ("l10n_fr.tax_report_17", "l10n_fr_account.tax_report_17"),
    ("l10n_fr.tax_report_18", "l10n_fr_account.tax_report_18"),
    ("l10n_fr.tax_report_19", "l10n_fr_account.tax_report_19"),
    ("l10n_fr.tax_report_20", "l10n_fr_account.tax_report_20"),
    ("l10n_fr.tax_report_21", "l10n_fr_account.tax_report_21"),
    ("l10n_fr.tax_report_22", "l10n_fr_account.tax_report_22"),
    ("l10n_fr.tax_report_22A", "l10n_fr_account.tax_report_22A"),
    ("l10n_fr.tax_report_23", "l10n_fr_account.tax_report_23"),
    ("l10n_fr.tax_report_24", "l10n_fr_account.tax_report_24"),
    ("l10n_fr.tax_report_25", "l10n_fr_account.tax_report_25"),
    ("l10n_fr.tax_report_27", "l10n_fr_account.tax_report_27"),
    ("l10n_fr.tax_report_28", "l10n_fr_account.tax_report_28"),
    ("l10n_fr.tax_report_29", "l10n_fr_account.tax_report_29"),
    ("l10n_fr.tax_report_2C", "l10n_fr_account.tax_report_2C"),
    ("l10n_fr.tax_report_2E", "l10n_fr_account.tax_report_2E"),
    ("l10n_fr.tax_report_32", "l10n_fr_account.tax_report_32"),
    ("l10n_fr.tax_report_5B", "l10n_fr_account.tax_report_5B"),
    ("l10n_fr.tax_report_9B_base", "l10n_fr_account.tax_report_9B_base"),
    ("l10n_fr.tax_report_9B_taxe", "l10n_fr_account.tax_report_9B_taxe"),
    ("l10n_fr.tax_report_A1", "l10n_fr_account.tax_report_A1"),
    ("l10n_fr.tax_report_A2", "l10n_fr_account.tax_report_A2"),
    ("l10n_fr.tax_report_A3", "l10n_fr_account.tax_report_A3"),
    ("l10n_fr.tax_report_A4", "l10n_fr_account.tax_report_A4"),
    ("l10n_fr.tax_report_A5", "l10n_fr_account.tax_report_A5"),
    ("l10n_fr.tax_report_AA", "l10n_fr_account.tax_report_AA"),
    ("l10n_fr.tax_report_AB", "l10n_fr_account.tax_report_AB"),
    ("l10n_fr.tax_report_B1", "l10n_fr_account.tax_report_B1"),
    ("l10n_fr.tax_report_B2", "l10n_fr_account.tax_report_B2"),
    ("l10n_fr.tax_report_B3", "l10n_fr_account.tax_report_B3"),
    ("l10n_fr.tax_report_B4", "l10n_fr_account.tax_report_B4"),
    ("l10n_fr.tax_report_B5", "l10n_fr_account.tax_report_B5"),
    ("l10n_fr.tax_report_E1", "l10n_fr_account.tax_report_E1"),
    ("l10n_fr.tax_report_E2", "l10n_fr_account.tax_report_E2"),
    ("l10n_fr.tax_report_E3", "l10n_fr_account.tax_report_E3"),
    ("l10n_fr.tax_report_E4", "l10n_fr_account.tax_report_E4"),
    ("l10n_fr.tax_report_E5", "l10n_fr_account.tax_report_E5"),
    ("l10n_fr.tax_report_E6", "l10n_fr_account.tax_report_E6"),
    ("l10n_fr.tax_report_F1", "l10n_fr_account.tax_report_F1"),
    ("l10n_fr.tax_report_F2", "l10n_fr_account.tax_report_F2"),
    ("l10n_fr.tax_report_F3", "l10n_fr_account.tax_report_F3"),
    ("l10n_fr.tax_report_F4", "l10n_fr_account.tax_report_F4"),
    ("l10n_fr.tax_report_F5", "l10n_fr_account.tax_report_F5"),
    ("l10n_fr.tax_report_F6", "l10n_fr_account.tax_report_F6"),
    ("l10n_fr.tax_report_F7", "l10n_fr_account.tax_report_F7"),
    ("l10n_fr.tax_report_F8", "l10n_fr_account.tax_report_F8"),
    ("l10n_fr.tax_report_F9", "l10n_fr_account.tax_report_F9"),
    ("l10n_fr.tax_report_I1_base", "l10n_fr_account.tax_report_I1_base"),
    ("l10n_fr.tax_report_I1_taxe", "l10n_fr_account.tax_report_I1_taxe"),
    ("l10n_fr.tax_report_I2_base", "l10n_fr_account.tax_report_I2_base"),
    ("l10n_fr.tax_report_I2_taxe", "l10n_fr_account.tax_report_I2_taxe"),
    ("l10n_fr.tax_report_I3_base", "l10n_fr_account.tax_report_I3_base"),
    ("l10n_fr.tax_report_I3_taxe", "l10n_fr_account.tax_report_I3_taxe"),
    ("l10n_fr.tax_report_I4_base", "l10n_fr_account.tax_report_I4_base"),
    ("l10n_fr.tax_report_I4_taxe", "l10n_fr_account.tax_report_I4_taxe"),
    ("l10n_fr.tax_report_I5_base", "l10n_fr_account.tax_report_I5_base"),
    ("l10n_fr.tax_report_I5_taxe", "l10n_fr_account.tax_report_I5_taxe"),
    ("l10n_fr.tax_report_I6_base", "l10n_fr_account.tax_report_I6_base"),
    ("l10n_fr.tax_report_I6_taxe", "l10n_fr_account.tax_report_I6_taxe"),
    ("l10n_fr.tax_report_P1_base", "l10n_fr_account.tax_report_P1_base"),
    ("l10n_fr.tax_report_P1_taxe", "l10n_fr_account.tax_report_P1_taxe"),
    ("l10n_fr.tax_report_P2_base", "l10n_fr_account.tax_report_P2_base"),
    ("l10n_fr.tax_report_P2_taxe", "l10n_fr_account.tax_report_P2_taxe"),
    ("l10n_fr.tax_report_T1_base", "l10n_fr_account.tax_report_T1_base"),
    ("l10n_fr.tax_report_T1_taxe", "l10n_fr_account.tax_report_T1_taxe"),
    ("l10n_fr.tax_report_T2_base", "l10n_fr_account.tax_report_T2_base"),
    ("l10n_fr.tax_report_T2_taxe", "l10n_fr_account.tax_report_T2_taxe"),
    ("l10n_fr.tax_report_T3_base", "l10n_fr_account.tax_report_T3_base"),
    ("l10n_fr.tax_report_T3_taxe", "l10n_fr_account.tax_report_T3_taxe"),
    ("l10n_fr.tax_report_T4_base", "l10n_fr_account.tax_report_T4_base"),
    ("l10n_fr.tax_report_T4_taxe", "l10n_fr_account.tax_report_T4_taxe"),
    ("l10n_fr.tax_report_T5_base", "l10n_fr_account.tax_report_T5_base"),
    ("l10n_fr.tax_report_T5_taxe", "l10n_fr_account.tax_report_T5_taxe"),
    ("l10n_fr.tax_report_T6_base", "l10n_fr_account.tax_report_T6_base"),
    ("l10n_fr.tax_report_T6_taxe", "l10n_fr_account.tax_report_T6_taxe"),
    ("l10n_fr.tax_report_T7_base", "l10n_fr_account.tax_report_T7_base"),
    ("l10n_fr.tax_report_T7_taxe", "l10n_fr_account.tax_report_T7_taxe"),
    ("l10n_fr.tax_report_TD", "l10n_fr_account.tax_report_TD"),
    ("l10n_fr.tax_report_TICC", "l10n_fr_account.tax_report_TICC"),
    ("l10n_fr.tax_report_TICFE", "l10n_fr_account.tax_report_TICFE"),
    ("l10n_fr.tax_report_TICGN", "l10n_fr_account.tax_report_TICGN"),
    ("l10n_fr.tax_report_TIC_total", "l10n_fr_account.tax_report_TIC_total"),
    ("l10n_fr.tax_report_X1", "l10n_fr_account.tax_report_X1"),
    ("l10n_fr.tax_report_X2", "l10n_fr_account.tax_report_X2"),
    ("l10n_fr.tax_report_X3", "l10n_fr_account.tax_report_X3"),
    ("l10n_fr.tax_report_X4", "l10n_fr_account.tax_report_X4"),
    ("l10n_fr.tax_report_X5", "l10n_fr_account.tax_report_X5"),
    ("l10n_fr.tax_report_Y1", "l10n_fr_account.tax_report_Y1"),
    ("l10n_fr.tax_report_Y2", "l10n_fr_account.tax_report_Y2"),
    ("l10n_fr.tax_report_Y3", "l10n_fr_account.tax_report_Y3"),
    ("l10n_fr.tax_report_Y4", "l10n_fr_account.tax_report_Y4"),
    ("l10n_fr.tax_report_Y5", "l10n_fr_account.tax_report_Y5"),
    ("l10n_fr.tax_report_Y6", "l10n_fr_account.tax_report_Y6"),
    ("l10n_fr.tax_report_Z1", "l10n_fr_account.tax_report_Z1"),
    ("l10n_fr.tax_report_Z2", "l10n_fr_account.tax_report_Z2"),
    ("l10n_fr.tax_report_Z3", "l10n_fr_account.tax_report_Z3"),
    ("l10n_fr.tax_report_Z4", "l10n_fr_account.tax_report_Z4"),
    ("l10n_fr.tax_report_Z5", "l10n_fr_account.tax_report_Z5"),
    ("l10n_fr.tax_report_credit", "l10n_fr_account.tax_report_credit"),
    (
        "l10n_fr.tax_report_credit_constate",
        "l10n_fr_account.tax_report_credit_constate",
    ),
    ("l10n_fr.tax_report_credit_impute", "l10n_fr_account.tax_report_credit_impute"),
    ("l10n_fr.tax_report_decompte_tva", "l10n_fr_account.tax_report_decompte_tva"),
    ("l10n_fr.tax_report_determination", "l10n_fr_account.tax_report_determination"),
    (
        "l10n_fr.tax_report_montant_op_realisees",
        "l10n_fr_account.tax_report_montant_op_realisees",
    ),
    (
        "l10n_fr.tax_report_op_imposables_ht",
        "l10n_fr_account.tax_report_op_imposables_ht",
    ),
    (
        "l10n_fr.tax_report_op_non_imposables",
        "l10n_fr_account.tax_report_op_non_imposables",
    ),
    ("l10n_fr.tax_report_regularisation", "l10n_fr_account.tax_report_regularisation"),
    ("l10n_fr.tax_report_reliquat", "l10n_fr_account.tax_report_reliquat"),
    ("l10n_fr.tax_report_tic_tax", "l10n_fr_account.tax_report_tic_tax"),
    ("l10n_fr.tax_report_tva_brute", "l10n_fr_account.tax_report_tva_brute"),
    (
        "l10n_fr.tax_report_tva_brute_autre",
        "l10n_fr_account.tax_report_tva_brute_autre",
    ),
    ("l10n_fr.tax_report_tva_brute_dom", "l10n_fr_account.tax_report_tva_brute_dom"),
    (
        "l10n_fr.tax_report_tva_brute_import",
        "l10n_fr_account.tax_report_tva_brute_import",
    ),
    (
        "l10n_fr.tax_report_tva_brute_metropo",
        "l10n_fr_account.tax_report_tva_brute_metropo",
    ),
    (
        "l10n_fr.tax_report_tva_brute_petrolier",
        "l10n_fr_account.tax_report_tva_brute_petrolier",
    ),
    ("l10n_fr.tax_report_tva_deductible", "l10n_fr_account.tax_report_tva_deductible"),
    (
        "l10n_fr.display_name_in_footer_param",
        "l10n_fr_account.display_name_in_footer_param",
    ),
    (
        "l10n_fr.account_reports_fr_statements_menu",
        "l10n_fr_account.account_reports_fr_statements_menu",
    ),
]


@openupgrade.migrate()
def migrate(env, version):
    openupgrade.rename_xmlids(env.cr, _xmlids_renames)
    openupgrade.logged_query(  # just in case `account_fr_fec` was not installed
        env.cr,
        """
        UPDATE ir_module_module
        SET state='to install'
        WHERE name = 'l10n_fr_account' AND state='uninstalled'""",
    )
